@@ -10,6 +10,11 @@ fn html_root_url() {
     assert_html_root_url_updated!("src/lib.rs");
 }
 
+#[test]
+fn cargo_versions() {
+    assert_contains_regex!("Cargo.toml", "^documentation = \"https://docs\\.rs/assert-panic/{version}/assert-panic/macro\\.assert_panic\\.html\"$");
+}
+
 #[test]
 fn readme_versions() {
     assert_contains_regex!("README.md", "\\[!\\[docs.rs]\\(https://docs.rs/assert-panic/badge.svg\\?version={version}\\)\\]\\(https://docs.rs/assert-panic/{version}/assert_panic/macro.assert_panic.html\\)");
